@@ -2,8 +2,6 @@
  *
  * rdfproc.c - Redland RDF command processor
  *
- * $Id: rdfproc.c 12987 2007-10-22 07:42:51Z laalto $
- *
  * Copyright (C) 2000-2007, David Beckett http://purl.org/net/dajobe/
  * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
@@ -167,6 +165,10 @@ static const char *default_storage_options="hash-type='bdb',dir='.'";
 static int
 log_handler(void *user_data, librdf_log_message *message) 
 {
+#ifdef RAPTOR_V2_AVAILABLE
+  librdf_world* world = (librdf_world*)user_data;
+#endif
+
   /* int code=message->code; */ /* The error code */
   raptor_locator *locator=(raptor_locator*)(message->locator);
 
@@ -180,7 +182,11 @@ log_handler(void *user_data, librdf_log_message *message)
     fprintf(stderr, "%s: Error - ", program);
 
   if(locator) { /* && message->facility == LIBRDF_FROM_PARSER) */
+#ifdef RAPTOR_V2_AVAILABLE
+    raptor_print_locator_v2(librdf_world_get_raptor(world), stderr, locator);
+#else
     raptor_print_locator(stderr, locator); 
+#endif
     fputc(':', stderr);
     fputc(' ', stderr);
  }
@@ -297,7 +303,7 @@ main(int argc, char *argv[])
 
   world=librdf_new_world();
 
-  librdf_world_set_logger(world, NULL, log_handler);
+  librdf_world_set_logger(world, world, log_handler);
 
   librdf_world_open(world);
 
@@ -423,16 +429,17 @@ main(int argc, char *argv[])
             for(i=0; 1; i++) {
               const char *format_name;
               const char *format_label;
-              if(rasqal_query_results_formats_enumerate_full(i,
-                                                             &format_name, 
-                                                             &format_label,
-                                                             NULL, NULL))
+              if(rasqal_query_results_formats_enumerate(world->rasqal_world_ptr,
+                                                        i,
+                                                        &format_name, 
+                                                        &format_label,
+                                                        NULL, NULL, NULL))
                 break;
               printf("  %-20s  %s\n", format_name, format_label);
             }
             exit(0);
           } else {
-            if(rasqal_query_results_formats_check(optarg, NULL, NULL))
+            if(rasqal_query_results_formats_check(world->rasqal_world_ptr, optarg, NULL, NULL))
               results_format=optarg;
             else {
               fprintf(stderr, "%s: invalid argument `%s' for `" HELP_ARG(r, results) "'\nTry '%s " HELP_ARG(r, results) " help' for a list of valid formats\n",
